@@ -19,7 +19,7 @@ HELP = f"""
 trim reads from single or paired fastq files
 expect all sequences (reads and adapters) to be 5' -> 3' oriented
 paired-end reads are only trimmed if adapter present at same place in both reads
-reads or pairs order may not be preserved if --parallel > 1 or --deduplicate set
+reads or pairs order may not be preserved if --parallel > 1
 
 arguments:
   -i --inputs       input fastq paths (single or r1 and r2, may be gzipped)
@@ -30,7 +30,7 @@ arguments:
   -a --adapters     adapter sequences to trim
                     optional, none by default
   -e --extremity    aggressively trim partial adapters from reads 3' extremity
-                    if at least the specified number of base pairs are matching
+                    if at least the given number of base pairs are matching
                     specify "full" to only trim full adapter sequences
                     optional, 1 by default
   -5 --cut-5        base pairs to cut off from reads 5' extremity
@@ -39,17 +39,17 @@ arguments:
                     optional, 0 by default
   -l --min-length   remove reads or pairs with a read shorter after trimming
                     optional, 25 by default
-  -d --deduplicate  keep only one of duplicated reads or pairs using each read first
-                    specified number of base pairs as matching sequence (done after
+  -d --deduplicate  keep one of duplicated reads or pairs using each read first given
+                    number of base pairs (eg, 25) as matching sequence (done after
                     trimming and consume ~12 GB of memory per 100 M reads or pairs)
                     optional, not done by default
 
 technical arguments:
   -p --parallel     number of parallel trimming processes to spawn
                     optional, 1 by default
-  -c --chunk-size   inputs read chunk size in bytes
+  -c --chunk-size   input files read chunk size in bytes
                     optional, 10485760 (10 MB) by default
-  -g --gz-level     output gzip compression level (1 to 9)
+  -z --z-level      output files gzip compression level (0 to 9)
                     optional, 1 by default
   -h --help         print help message and exit
   -v --version      print version and exit (v. {VERSION})
@@ -70,10 +70,10 @@ def gz_open(path, mode="r", level=6, is_gz="infer", infer_mode="auto", **open_ka
 def infer_gz(path, mode="auto"):
     if mode == "extension":
         return path.lower().endswith(".gz")
-    elif mode == "magic":
+    if mode == "magic":
         with open(path, "rb") as file:
             return file.read(2) == b"\x1f\x8b"
-    elif mode == "auto":
+    if mode == "auto":
         return infer_gz(path, "magic" if os.path.isfile(path) else "extension")
     raise ValueError(f"invalid infer mode: {mode} (auto, magic or extension)")
 
@@ -224,7 +224,7 @@ def sync_process(sync_queue_in, sync_queue_out, read_process_count):
             sync_queue_out.put([send_size, keep_going])
 
 
-def trim_process(adapters, input_queues, input_lock, cut_5, cut_3, min_length, deduplicate_items, gz_levels, output_queues, output_lock):
+def trim_process(adapters, input_queues, input_lock, cut_5, cut_3, min_length, deduplicate_items, z_levels, output_queues, output_lock):
     adapters, adapters_tree = adapters
     deduplicate, deduplicate_in_queue, deduplicate_out_queue, deduplicate_lock = deduplicate_items
     counts = [0, 0, 0, 0] # total, full_adapter, below_min_length, duplicates_removed
@@ -269,13 +269,13 @@ def trim_process(adapters, input_queues, input_lock, cut_5, cut_3, min_length, d
             counts[3] += len(hash_values) - len(keep_indexes)
             for index, entries in enumerate(output_batch):
                 output_batch[index] = [entries[keep_index] for keep_index in keep_indexes]
-        for index, (entries, gz_level) in enumerate(zip(output_batch, gz_levels)):
+        for index, (entries, z_level) in enumerate(zip(output_batch, z_levels)):
             if entries:
                 entries = "\n".join("\n".join(entry) for entry in entries).encode() + b"\n"
             else:
                 entries = b""
-            if gz_level >= 0:
-                entries = gzip.compress(entries, compresslevel=gz_level)
+            if z_level >= 0:
+                entries = gzip.compress(entries, compresslevel=z_level)
             output_batch[index] = entries
         with output_lock:
             for output_queue, entries in zip(output_queues, output_batch):
@@ -394,9 +394,9 @@ class Controller:
         return results, self.runtime
 
 
-def trim_reads(input_paths, output_paths, adapters, extremity, cut_5, cut_3, min_length, deduplicate, parallel, chunk_size, gz_level):
+def trim_reads(input_paths, output_paths, adapters, extremity, cut_5, cut_3, min_length, deduplicate, parallel, chunk_size, z_level):
     input_paths, output_paths = prepare_fastq_paths(input_paths, output_paths)
-    gz_levels = [gz_level if infer_gz(output_path, "extension") else -1 for output_path in output_paths]
+    z_levels = [z_level if infer_gz(output_path, "extension") else -1 for output_path in output_paths]
     adapters = prepare_adapters(adapters, extremity)
     log(f"--- trim reads (v. {VERSION}) ---")
     log(f"inputs: {' '.join(input_paths)}")
@@ -425,7 +425,7 @@ def trim_reads(input_paths, output_paths, adapters, extremity, cut_5, cut_3, min
         [sync_queue_in, sync_queue_out, len(input_paths)])
     for _ in range(parallel):
         controller.register("trim", trim_process,
-            [adapters, input_queues, input_lock, cut_5, cut_3, min_length, deduplicate_items, gz_levels, output_queues, output_lock])
+            [adapters, input_queues, input_lock, cut_5, cut_3, min_length, deduplicate_items, z_levels, output_queues, output_lock])
     if deduplicate:
         controller.register("deduplicate", deduplicate_process,
             [deduplicate_in_queue, deduplicate_out_queue, parallel])
@@ -480,7 +480,7 @@ def main(raw_args):
     parser.add_argument("-d", "--deduplicate", default=None, type=int)
     parser.add_argument("-p", "--parallel", default=1, type=int)
     parser.add_argument("-c", "--chunk-size", default=10485760, type=int)
-    parser.add_argument("-g", "--gz-level", default=1, type=int)
+    parser.add_argument("-z", "--z-level", default=1, type=int)
     args = vars(parser.parse_args(raw_args)).values()
     
     return trim_reads(*args)
